These are internal functions for printing and calculating quantities such as additive K-factors and multiplicative Delta-Factors that determine a specified M extent-of-shrinkage. RXmstep() is called by RXridge(), RXtrisk() and RXtsimu().
RXmstep(mobj, kinc, p, qp, eqm1)Newest objective value for the M-extent-of-shrinkage along a path of shape qp.
Previous additive eigenvalue inflation constant yielding a smaller mobj.
Number of elements in the regression coefficient vector.
Shrinkage path Q-shape parameter.
Vector of X'X eigenvalues raised to the power (qp-1).
An output list consisting of two objects:
New, increased value of kinc that produces an M-extent-of-shrinkage = mobj.
A pxp diagonal matrix of multiplicative shrinkage (delta) factors for the uncorrelated components of the regression coefficient vector.