RXshrink-package: Maximum Likelihood Shrinkage via Generalized Ridge or Least Angle Regression
Description
The functions in this package augment the basic calculations of Generalized
Ridge and Least Angle Regression with important visualization tools. Specifically, they display
TRACEs of normal-distribution-theory Maximum Likelihood estimates of the key quantities that
completely characterize the effects of shrinkage on the MSE Risk of fitted coefficients.
Arguments
Details
ll{
Package: RXshrink
Type: Package
Version: 1.0-7
Date: 2011-12-24
License: GNU GENERAL PUBLIC LICENSE, Version 2, June 1991
}
RXridge() calculates and displays TRACEs for the Q-shaped shrinkage path, including
the M-extent of shrinkage along that path, that are most likely under normal
distribution theory to yield optimal reducions in MSE Risk.
When regression parameters have specified, KNOWN numerical values, RXtrisk() calculates and
displays the corresponding True MSE Risk profiles and RXtsimu() first simulates Y-outcome data
then calculates true Squared Error Losss associated with Q-shape shrinkage.
RXlarlso() calls the Efron/Hastie lars() R-function to perform Least Angle Regression then
augments these calculations with Maximum Likelihood TRACE displays like those of RXridge().
RXuclars() applies Least Angle Regression to the uncorrelated components of a possibly
ill-conditioned set of X-variables using a closed-form expression for the lars/lasso
shrinkage delta factors that exits in this special case.
References
Efron B, Hastie T, Johnstone I, Tibshirani R. (2004) Least angle regression.
Ann. Statis.32, 407-499.
Goldstein M, Smith AFM. (1974) Ridge-type estimators for regression analysis.
J. Roy. Stat. Soc. B36, 284-291. (2-parameter shrinkage family.)
Obenchain RL. (2005)
Shrinkage Regression: ridge, BLUP, Bayes, spline and Stein. Electronic
book-in-progress (200+ pages.) http://members.iquest.net/~softrx/.
Obenchain RL. (2011) shrink.PDF RXshrink package vignette.