Learn R Programming

RXshrink (version 1.0-5)

RXuclars: Maximum Likelihood Least Angle Regression on Uncorrelated X-Components

Description

Apply least angle regression estimation to the uncorrelated components of a possibly ill-conditioned linear regression model and generate normal-theory maximum likelihood TRACE displays.

Usage

RXuclars(form, data, rscale = 1, type = "lar", trace = FALSE, 
    eps = .Machine$double.eps, omdmin = 9.9e-13, ...)

Arguments

form
A regression formula [y~x1+x2+...] suitable for use with lm().
data
Data frame containing observations on all variables in the formula.
rscale
One of three possible choices (0, 1 or 2) for rescaling of variables as they are being "centered" to remove non-essential ill-conditioning: 0 implies no rescaling; 1 implies divide each variable by its standard error; 2 implies rescale as in
type
One of "lasso", "lar" or "forward.stagewise" for function lars(). Names can be abbreviated to any unique substring. Default in RXlarlso() is "lar".
trace
If TRUE, lars() function prints out its progress.
eps
The effective zero for lars().
omdmin
Strictly positive minimum allowed value for one-minus-delta (default = 9.9e-013.)
...
Optional argument(s) passed to the lars() function in the lars R-package.

Value

  • An output list object of class RXuclars:
  • formThe regression formula specified as the first argument.
  • dataName of the data.frame object specified as the second argument.
  • pNumber of regression predictor variables.
  • nNumber of complete observations after removal of all missing values.
  • r2Numerical value of R-square goodness-of-fit statistic.
  • s2Numerical value of the residual mean square estimate of error.
  • prinstatListing of principal statistics.
  • gmatOrthogonal matrix of direction cosines for regressor principal axes.
  • larsAn object of class lars.
  • coefMatrix of shrinkage-ridge regression coefficient estimates.
  • riskMatrix of MSE risk estimates for fitted coefficients.
  • exevMatrix of excess MSE eigenvalues (ordinary least squares minus ridge.)
  • infdMatrix of direction cosines for the estimated inferior direction, if any.
  • spatMatrix of shrinkage pattern multiplicative delta factors.
  • mlikListing of criteria for maximum likelihood selection of M-extent-of-shrinkage.
  • sextListing of summary statistics for all M-extents-of-shrinkage.

Details

RXuclars() applies Least Angle Regression to the uncorrelated components of a possibly ill-conditioned set of X-variables. A closed-form expression for the lars/lasso shrinkage delta factors exits in this case: Delta(i) = max(0,1-k/abs[PC(i)]), where PC(i) is the principal correlation between Y and the i-th principal coordinates of X. Note that the k-factor in this formulation is limited to a subset of [0,1]. MCAL=0 occurs at k=0, while MCAL = P results when k is the maximum absolute principal correlation.

References

Efron B, Hastie T, Johnstone I, Tibshirani R. (2004) Least angle regression. Ann. Statis. 32, 407-499 (with discussion.) Obenchain RL. (1994-2005) Shrinkage Regression: ridge, BLUP, Bayes, spline and Stein. members.iquest.net/~softrx. Obenchain RL. (2010) RXshrink-R.PDF ../R_HOME/library/RXshrink/doc

See Also

RXlarlso.

Examples

Run this code
data(longley2)
  form <- GNP~GNP.deflator+Unemployed+Armed.Forces+Population+Year+Employed
  rxuobj <- RXuclars(form, data=longley2)
  rxuobj
  plot(rxuobj)

Run the code above in your browser using DataLab