Learn R Programming

RXshrink (version 1.0-6)

haldport: Portland Cement benchmark of Hald(1952)

Description

Heat evolved during setting of 13 cement mixtures of four basic ingredients. Each ingredient percentage appears to be rounded down to a full integer. The sum of the four mixture percentages varies from a maximum of 99% to a minimum of 95%. If all four regressor X-variables always summed to 100%, the centered X-matrix would then be of rank only 3. Thus, the regression of heat on four X-percentages is ill-conditioned, with an approximate rank deficiency of MCAL = 1.

Usage

data(haldport)

Arguments

source

Woods H, Steinour HH, Starke HR. "Effect of composition of Portland cement on heat evolved during hardening. Industrial Engineering and Chemistry 1932; 24: 1207-1214.

Details

The (RXshrink) haldport data are identical to the (MASS) cement data except for variable names.

References

Hald A. Statistical Theory with Engineering Applications. 1952 (page 647.) New York; Wiley.