Usage
RXridge(form, data, rscale = 1, Q = "qmse", steps = 8, nq = 21,
qmax = 5, qmin = -5, omdmin = 9.9e-13)Arguments
form
A regression formula [y~x1+x2+...] suitable for use with lm().
data
Data frame containing observations on all variables in the formula.
rscale
One of three possible choices (0, 1 or 2) for rescaling of variables
as they are being "centered" to remove non-essential ill-conditioning: 0 implies no
rescaling; 1 implies divide each variable by its standard error; 2 implies rescale as
in
Q
Shape parameter that controls the curvature of the shrinkage path through
regression-coefficient likelihood space (default = "qmse" implies use the value found
most likely to be optimal.) Use Q = 0 to specify Hoerl-Kennard "ordinary" ridge regre
steps
Number of equally spaced values per unit change along the horizontal
M-extent-of-shrinkage axis for estimates to be calculated and displayed in TRACES
(default = 8.)
nq
Number of equally spaced values on the lattice of all possible values for
shrinkage Q-shape between the "qmin" and "qmax" parameter settings (default = 21.)
qmax
Maximum allowed Q-shape (default = +5.)
qmin
Minimum allowed Q-shape (default = -5.)
omdmin
Strictly positive minimum allowed value for one-minus-delta (default = 9.9e-013.)