The functions in this package augment the basic calculations of Generalized Ridge and Least Angle Regression with important visualization tools. Specifically, they display TRACEs of estimates for 5 KEY quantities (fitted coefficients, MSE risks, excess eigenvalues, inferior direction cosines and shrinkage factors) that completely characterize the effects of shrinkage along 2-parameter Paths (Q-shape and M-extent) through likelihood space. Most paths start at the Ordinary Least-Squares estimate [M = 0] and end at the origin, (0, 0, ..., 0) where all coefficient estimates have been shrunken to zero [M = rank(X).] Three different types of Likelihood of minimal MSE risk (Classical Normal-Theory, Empirical Bayes, and Random Coefficients) are monitored to suggest an optimal M-extent of shrinkage.
| Package: | RXshrink |
| Type: | Package |
| Version: | 1.1 |
| Date: | 2018-11-06 |
| License: | GNU GENERAL PUBLIC LICENSE, Version 2, June 1991 |
RXridge() calculates and displays TRACEs for the Q-shaped shrinkage path, including the M-extent of shrinkage along that path, that are most likely under normal distribution theory to yield optimal reductions in MSE Risk.
When regression parameters have specified, KNOWN numerical values, RXtrisk() calculates and displays the corresponding True MSE Risk profiles and RXtsimu() first simulates Y-outcome data then calculates true Squared Error Losses associated with Q-shape shrinkage.
RXlarlso() calls the Efron/Hastie lars() R-function to perform Least Angle Regression then augments these calculations with Maximum Likelihood TRACE displays like those of RXridge().
RXuclars() applies Least Angle Regression to the uncorrelated components of a possibly ill-conditioned set of X-variables using a closed-form expression for the lars/lasso shrinkage delta factors that exits in this special case.
RXsigns() displays the normal-theory maximum likelihood estimate of the B(=) regression coefficient vector that minimizes MSE Risk in the unknown direction of p-space PARALLEL to the true Beta vector. This estimate corrects "wrong-sign" problems in the sense that its coefficients have the same relative magnitudes and numerical signs as those of the "Correlation Form" of the X'y vector.
Efron B, Hastie T, Johnstone I, Tibshirani R. (2004) Least angle regression. Annals of Statistics 32, 407-499.
Goldstein M, Smith AFM. (1974) Ridge-type estimators for regression analysis. J. Roy. Stat. Soc. B 36, 284-291. (The 2-parameter shrinkage family.)
Obenchain RL. (2005) Shrinkage Regression: ridge, BLUP, Bayes, spline and Stein. Electronic book-in-progress (185+ pages.) http://localcontrolstatistics.org
Obenchain RL. (2018) RXshrink_in_R.PDF RXshrink package vignette-like file. http://localcontrolstatistics.org
# NOT RUN {
demo(longley2)
# }
Run the code above in your browser using DataLab